@@ -40,7 +40,6 @@
 #include "fr-command.h"
 #include "fr-command-tar.h"
 
-#define ACTIVITY_DELAY 20
 #define LSTAR_DATE_FORMAT "%Y-%m-%d %H:%M"
 
 static void fr_command_tar_class_init  (FrCommandTarClass *class);
@@ -837,9 +836,6 @@ get_uncompressed_name (FrCommandTar *c_tar,
 }
 
 
-#define MAX_TRIES 50
-
-
 static char *
 get_temp_name (FrCommandTar *c_tar,
 	       const char   *filepath)
