@@ -17,9 +17,10 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <config.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
@@ -93,8 +94,7 @@ fr_command_info_free (FrCommandInfo *info)
 		return;
 
 	if (info->args != NULL) {
-		g_list_foreach (info->args, (GFunc) g_free, NULL);
-		g_list_free (info->args);
+		g_list_free_full (info->args, g_free);
 		info->args = NULL;
 	}
 
@@ -173,8 +173,7 @@ fr_channel_data_reset (FrChannelData *channel)
 	fr_channel_data_close_source (channel);
 
 	if (channel->raw != NULL) {
-		g_list_foreach (channel->raw, (GFunc) g_free, NULL);
-		g_list_free (channel->raw);
+		g_list_free_full (channel->raw, g_free);
 		channel->raw = NULL;
 	}
 }
@@ -244,7 +243,8 @@ fr_process_get_type (void)
 			NULL,
 			sizeof (FrProcess),
 			0,
-			(GInstanceInitFunc) fr_process_init
+			(GInstanceInitFunc) fr_process_init,
+			NULL
 		};
 
 		type = g_type_register_static (G_TYPE_OBJECT,
@@ -640,8 +640,11 @@ child_setup (gpointer user_data)
 {
 	FrProcess *process = user_data;
 
-	if (process->priv->use_standard_locale)
-		putenv ("LC_ALL=C");
+	if (process->priv->use_standard_locale) {
+		putenv ("LC_MESSAGES=C");
+		putenv ("LC_TIME=C");
+		putenv ("LC_NUMERIC=C");
+	}
 
 	/* detach from the tty */
 
@@ -740,12 +743,15 @@ start_current_command (FrProcess *process)
 
 	argv[i] = NULL;
 
-#ifdef DEBUG
+#ifdef MATE_ENABLE_DEBUG
 	{
 		int j;
 
-		if (process->priv->use_standard_locale)
-			g_print ("\tLC_ALL=C\n");
+		if (process->priv->use_standard_locale) {
+			g_print ("\tLC_MESSAGES=C\n");
+			g_print ("\tLC_TIME=C\n");
+			g_print ("\tLC_NUMERIC=C\n");
+		}
 
 		if (info->dir != NULL)
 			g_print ("\tcd %s\n", info->dir);
@@ -947,7 +953,7 @@ check_child (gpointer data)
 	if (continue_process) {
 		if (process->error.type != FR_PROC_ERROR_NONE) {
 			allow_sticky_processes_only (process, TRUE);
-#ifdef DEBUG
+#ifdef MATE_ENABLE_DEBUG
 			{
 				GList *scan;
 
@@ -1057,10 +1063,10 @@ fr_close_suspend_process(FrProcess *process)
     if (process->priv->suspend)
     {
         if (process->priv->command_pid > 0)
-        {    
+        {
             ret = killpg (process->priv->command_pid,SIGTERM);
             ret = killpg (process->priv->command_pid,SIGCONT);
-        }    
+        }
         if(ret == 0)
             process->priv->suspend = FALSE;
     }
