@@ -17,7 +17,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef TYPEDEFS_H
@@ -26,7 +26,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#define MEGABYTE (1024 * 1024)
+#define MEGABYTE (1024.0 * 1024.0)
 
 #define ADD_FOLDER_OPTIONS_DIR  "engrampa/options"
 
@@ -111,13 +111,13 @@ typedef struct {
 
 typedef struct {
 	const char    *mime_type;
-	char          *default_ext;
-	char          *name;
+	const char    *default_ext;
+	const char    *name;
 	FrCommandCaps  capabilities;
 } FrMimeTypeDescription;
 
 typedef struct {
-	char       *ext;
+	const char *ext;
 	const char *mime_type;
 } FrExtensionType;
 
